;The following script has been updated to work with Paradox 4.0.
;(It had contained nested procedure definitions which are not
;allowed in Paradox 4.0)
;======================= Begin Script ==================
;Lib = Currency ; Change to your library name here and remove the
; remarks on the 'Writelib' commands below the Endproc definitions
; to add this to your code

;Contents        : procedure tomoney 
;Source File     : TOMONEY.SC
;Submitted By    : John Frykland, Borland International
;Revised By      : Peter M. Jagielski, Borland International
;Revised By      : John Hawklyn, Borland International (3/5/93)
;Description     : This procedure accepts a numeric value and converts it to
;                  its English-worded equivalent.  et: 12.23 is returned as:
;                  a currency value of: TWELVE and 23/100
;Call Syntax     : tomoney(amt)
;Parameters      : amt = numeric dollar amount to be converted (<999,999.99)
;Returns Value?  : yes - English string equivalent of numeric amount
;Paradox Version : 2,3
;Special Notes   : This procedure will need to be modified in order to 
;                  correctly operate on negative numeric values.

  PROC hundsval(num)              ;following procedure is called by TOMONEY 
                                  ;to identify characteristic
   PRIVATE hun,ten,one,str        ; of number.
    hun = INT(num / 100)          ;determine number of hundreds
    num = num - (hun * 100)       ;tens and units
    ten = INT(num / 10)
    num = num - (ten * 10)
    one = INT(num)
    str = ""                      ;begin building string
    IF (hun > 0) THEN
      str = str + onestr[Hun] + "Hundred "
    ENDIF
    IF (ten > 0) THEN
      IF (ten > 1) THEN
        str = str + tenstr[Ten]           ;values 20 - 99
      ELSE
        str = str + onestr[One + 10]      ;values 1 - 19
      ENDIF
    ELSE
      IF (one > 0)  THEN
       str = str + onestr[One]            ;values 1 - 9
      ENDIF
    ENDIF
    IF (one > 0 AND ten > 1)  THEN
      str = str + onestr[One]             ;values 1 - 19
    ENDIF
    RETURN str
  ENDPROC ; HundsVal(Num)
; Writelib Lib HundsVal

  PROC genval(num)                ;following procedure is called by TOMONEY 
                                  ; to generate thousands
   PRIVATE thou,str
    thou = INT(num / 1000)        ;determine number of thousands
    num = num - (thou * 1000)
    str = hundsval(thou)          ;generate thousands if any
    IF (str <> "") THEN
      str = str + "Thousand "
    ENDIF
    RETURN str + hundsval(num)    ;generate rest of number
  ENDPROC ; GenVal(num)
;  Writelib Lib GenVal

PROC tomoney(amt)
 PRIVATE thou,str

  ARRAY onestr[19]
  ARRAY tenstr[9]
  onestr[1] = "One "
  onestr[2] = "Two "
  onestr[3] = "Three "
  onestr[4] = "Four "
  onestr[5] = "Five "
  onestr[6] = "Six "
  onestr[7] = "Seven "
  onestr[8] = "Eight "
  onestr[9] = "Nine "
  onestr[10] = "Ten "
  onestr[11] = "Eleven "
  onestr[12] = "Twelve "
  onestr[13] = "Thirteen "
  onestr[14] = "Fourteen "
  onestr[15] = "Fifteen "
  onestr[16] = "Sixteen "
  onestr[17] = "Seventeen "
  onestr[18] = "Eighteen "
  onestr[19] = "Nineteen "

  tenstr[1] = "?"
  tenstr[2] = "Twenty "
  tenstr[3] = "Thirty "
  tenstr[4] = "Forty "
  tenstr[5] = "Fifty "
  tenstr[6] = "Sixty "
  tenstr[7] = "Seventy "
  tenstr[8] = "Eighty "
  tenstr[9] = "Ninety "

  stramt = FORMAT("W9.2,SU",amt)
  offset = SEARCH(".",stramt) + 1
  cents  = SUBSTR(stramt,offset,2)
  spellamt = genval(amt)
  IF (spellamt = "") THEN
    spellamt = "0 "
  ENDIF
  stramt = spellamt + "and " + cents + "/100 Dollars"
  RETURN stramt
ENDPROC ; ToMoney(amt)
; Writelib Lib ToMoney
;================= End Script =======================
